========
Simplify
========

.. currentmodule:: sympy.simplify.simplify

simplify
--------
.. autofunction:: simplify

separatevars
------------
.. autofunction:: separatevars

nthroot
-------
.. autofunction:: nthroot

kroneckersimp
-------------
.. autofunction:: kroneckersimp

besselsimp
----------
.. autofunction:: besselsimp

hypersimp
---------
.. autofunction:: hypersimp

hypersimilar
------------
.. autofunction:: hypersimilar

nsimplify
---------
.. autofunction:: nsimplify

posify
------
.. autofunction:: posify

logcombine
----------
.. autofunction:: logcombine

Radsimp
-------
.. module:: sympy.simplify.radsimp

radsimp
^^^^^^^
.. autofunction:: radsimp

rad_rationalize
^^^^^^^^^^^^^^^
.. autofunction:: rad_rationalize

collect
^^^^^^^
.. autofunction:: collect

.. autofunction:: rcollect

collect_sqrt
^^^^^^^^^^^^
.. autofunction:: collect_sqrt

collect_const
^^^^^^^^^^^^^
.. autofunction:: collect_const

fraction
^^^^^^^^
.. autofunction:: fraction

Ratsimp
-------
.. module:: sympy.simplify.ratsimp

ratsimp
^^^^^^^
.. autofunction:: ratsimp

ratsimpmodprime
^^^^^^^^^^^^^^^
.. autofunction:: ratsimpmodprime

Trigonometric simplification
----------------------------
.. module:: sympy.simplify.trigsimp

trigsimp
^^^^^^^^
.. autofunction:: trigsimp

Power simplification
--------------------
.. module:: sympy.simplify.powsimp

powsimp
^^^^^^^
.. autofunction:: powsimp

powdenest
^^^^^^^^^
.. autofunction:: powdenest

Combinatorial simplification
----------------------------
.. module:: sympy.simplify.combsimp

combsimp
^^^^^^^^
.. autofunction:: combsimp

Square Root Denesting
---------------------
.. module:: sympy.simplify.sqrtdenest

sqrtdenest
^^^^^^^^^^
.. autofunction:: sqrtdenest

Common Subexpression Elimination
--------------------------------
.. module:: sympy.simplify.cse_main

cse
^^^
.. autofunction:: cse

opt_cse
^^^^^^^
.. autofunction:: sympy.simplify.cse_main::opt_cse

tree_cse
^^^^^^^^
.. autofunction:: sympy.simplify.cse_main::tree_cse

Hypergeometric Function Expansion
---------------------------------
.. module:: sympy.simplify.hyperexpand

hyperexpand
^^^^^^^^^^^
.. autofunction:: hyperexpand

EPath Tools
-----------
.. module:: sympy.simplify.epathtools

EPath class
^^^^^^^^^^^
.. autoclass:: EPath
   :members:

epath
^^^^^
.. autofunction:: epath
